==> lambdaless-0.1.6.tgz: package/spec/support/mockapievent.ts <==
import { APIGatewayEvent } from 'aws-lambda';


export function getMockAPIEvent(): APIGatewayEvent {
    return {
        resource: '/',
        path: '/',
        httpMethod: 'POST',
        headers: {
            Accept: 'text/html,application/json',
            'Accept-Encoding': 'gzip, deflate, br',
            'Accept-Language': 'en-US',
            'cache-control': 'max-age=0',
            'CloudFront-Forwarded-Proto': 'https',
            'CloudFront-Is-Desktop-Viewer': 'true',
            'CloudFront-Is-Mobile-Viewer': 'false',
            'CloudFront-Is-SmartTV-Viewer': 'false',
            'CloudFront-Is-Tablet-Viewer': 'false',
            'CloudFront-Viewer-Country': 'US',
            'content-type': 'application/json',
            Host: 'abc123.api.us-west-1.amazonaws.com',
            origin: 'https://abc123.api.us-west-1.amazonaws.com',
            Referer: 'https://abc123.api.us-west-1.amazonaws.com/dev/',
            'upgrade-insecure-requests': '1',
            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.115 Safari/537.36',
            Via: '2.0 a3650115c5e21e2b5d133ce84464bea3.cloudfront.net (CloudFront)',
            'X-Amz-Cf-Id': '0nDeiXnReyHYCkv8cc150MWCFCLFPbJoTs1mexDuKe2WJwK5ANgv2A==',
            'X-Amzn-Trace-Id': 'Root=1-597079de-75fec8453f6fd4812414a4cd',
            'X-Forwarded-For': '1.2.3.4, 1.2.3.5',
            'X-Forwarded-Port': '443',
            'X-Forwarded-Proto': 'https'
        },
        queryStringParameters: null,
        pathParameters: null,
        stageVariables: null,
        requestContext: {
            path: '/dev/',
            accountId: '125002137610',
            resourceId: 'qdolsr1yhk',
            stage: 'dev',
            requestId: '0f2431a2-6d2f-11e7-b75152aa497861',
            identity: {
                apiKey: '',
                accessKey: null,
                accountId: null,
                caller: null,
                cognitoIdentityId: null,
                cognitoIdentityPoolId: null,
                sourceIp: '1.2.3.6',
                cognitoAuthenticationType: null,
                cognitoAuthenticationProvider: null,
                user: null,
                userArn: null,
                userAgent: 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.115 Safari/537.36'
            },
            resourcePath: '/',
            httpMethod: 'POST',
            apiId: 'j3azlsj0c4'
        },
        body: '{"foo": "bar"}',
        isBase64Encoded: false
    } as APIGatewayEvent;
}

==> lambdaless-0.2.5.tgz: package/spec/support/mockapievent.ts <==
import { APIGatewayEvent } from 'aws-lambda';


export function getMockAPIEvent(): APIGatewayEvent {
    return {
        resource: '/',
        path: '/',
        httpMethod: 'POST',
        headers: {
            Accept: 'text/html,application/json',
            'Accept-Encoding': 'gzip, deflate, br',
            'Accept-Language': 'en-US',
            'cache-control': 'max-age=0',
            'CloudFront-Forwarded-Proto': 'https',
            'CloudFront-Is-Desktop-Viewer': 'true',
            'CloudFront-Is-Mobile-Viewer': 'false',
            'CloudFront-Is-SmartTV-Viewer': 'false',
            'CloudFront-Is-Tablet-Viewer': 'false',
            'CloudFront-Viewer-Country': 'US',
            'Content-Type': 'application/json',
            Host: 'abc123.api.us-west-1.amazonaws.com',
            origin: 'https://abc123.api.us-west-1.amazonaws.com',
            Referer: 'https://abc123.api.us-west-1.amazonaws.com/dev/',
            'upgrade-insecure-requests': '1',
            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.115 Safari/537.36',
            Via: '2.0 a3650115c5e21e2b5d133ce84464bea3.cloudfront.net (CloudFront)',
            'X-Amz-Cf-Id': '0nDeiXnReyHYCkv8cc150MWCFCLFPbJoTs1mexDuKe2WJwK5ANgv2A==',
            'X-Amzn-Trace-Id': 'Root=1-597079de-75fec8453f6fd4812414a4cd',
            'X-Forwarded-For': '1.2.3.4, 1.2.3.5',
            'X-Forwarded-Port': '443',
            'X-Forwarded-Proto': 'https'
        },
        queryStringParameters: null,
        pathParameters: null,
        stageVariables: null,
        requestContext: {
            path: '/dev/',
            accountId: '125002137610',
            resourceId: 'qdolsr1yhk',
            stage: 'dev',
            requestId: '0f2431a2-6d2f-11e7-b75152aa497861',
            identity: {
                apiKey: '',
                accessKey: null,
                accountId: null,
                caller: null,
                cognitoIdentityId: null,
                cognitoIdentityPoolId: null,
                sourceIp: '1.2.3.6',
                cognitoAuthenticationType: null,
                cognitoAuthenticationProvider: null,
                user: null,
                userArn: null,
                userAgent: 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.115 Safari/537.36'
            },
            resourcePath: '/',
            httpMethod: 'POST',
            apiId: 'j3azlsj0c4'
        },
        body: '{"foo": "bar"}',
        isBase64Encoded: false
    } as APIGatewayEvent;
}
